function [up, vp] = fgaus_pred_uv(yr, mon, dy, hr, mn, sec, LON, LAT)
%function [up, vp] = fgaus_pred_uv(yr, mon, dy, hr, mn, sec, LON, LAT)
% ***********************************************
%
% M Dunn 4/01
% ***********************************************
if nargin == 3
  LON = mon; LAT = dy;
  sec = yr(:,6); mn = yr(:,5); hr = yr(:,4);
  dy = yr(:,3); mon = yr(:,2); yr = yr(:,1);
end

% Times for the tidal analyses are referenced to Jan 1, 1994, 0000hrs
T = julian2([yr mon dy hr mn sec]) - julian2(1994,1,1,0);  % days

u = nan*ones(size(yr)); v = nan*ones(size(yr));

xm=LON(:);  ym=LAT(:); tm=T;

load gb_coeffs
lons = lons(4:end); lats = lats(4:end);
xa = lons';
ya = lats';
ns=length(xa);

% Calculate the distance matrix for the points to determine cos/sin amps
LC=.3;
nm = length(xm);
d1a=xm*ones(1,ns)-ones(nm,1)*xa;	% lon distance from knot to each pt 
d2a=ym*ones(1,ns)-ones(nm,1)*ya;	% lat distance from knot to each pt
dda=d1a.^2+d2a.^2;	% radial distance ^2 (deg) from each knot to each pt
Xm= exp(-dda/(2*LC*LC));		%Gaussian
		
%For the M2 tidal components      
aa = [A0 A1 A2 A3 A4 A5 A6 A7];		%size(82x16)

for i=1:8
  mcu(:,i) = Xm * aa(1:ns,1+(i-1)*2);	%tidal amplitude (cos-component)
  msu(:,i) = Xm * aa(ns+1:2*ns,1+(i-1)*2);	%tidal amplitude (sin-component)
  mcv(:,i) = Xm * aa(1:ns,2*i);	        %tidal amplitude (cos-component)
  msv(:,i) = Xm * aa(ns+1:2*ns,2*i);	%tidal amplitude (sin-component)
end

% Tidal frequencies (f) (in cyc/h): 
freq = [28.9841042 13.9430356 28.4397296 15.0410686 30 57.968208 86.952312...
115.9364169];
freq = (freq*24)/360;	% 1/day
for i=1:8
phc(:,i) = cos(2*pi*tm*freq(i));
phs(:,i) = sin(2*pi*tm*freq(i));
end

upp=(mcu.*phc)+(msu.*phs);
vpp=(mcv.*phc)+(msv.*phs);
up =sum(upp')';
vp =sum(vpp')';
